@@ -11,6 +11,7 @@ class ConnectionType(Enum):
     """
     Enumeration of connection type values from the GraphQL API
     """
+
     BigQuery = "BIGQUERY"
     DataLake = "DATA_LAKE"
     Hive = "HIVE"
@@ -47,6 +48,7 @@ class OnboardingConfiguration:
 
     create_warehouse: bool = True
 
+
 @dataclass_json(letter_case=LetterCase.CAMEL, undefined=Undefined.INCLUDE)
 @dataclass
 class ConnectionOptions:
@@ -59,18 +61,22 @@ class ConnectionOptions:
     skip_permission_tests: Optional[bool] = False
     auto_yes: Optional[bool] = False
 
-    monolith_connection_payload: dict = field(init=False)  # Additional options passed to the monolith (from client)
+    monolith_connection_payload: dict = field(
+        init=False
+    )  # Additional options passed to the monolith (from client)
 
     def __post_init__(self):
         self.monolith_connection_payload = {}
 
         if self.dc_id:
             self.dc_id = str(self.dc_id)
-            self.monolith_connection_payload['dcId'] = self.dc_id
+            self.monolith_connection_payload["dcId"] = self.dc_id
         if self.skip_validation:
-            self.monolith_connection_payload['skipValidation'] = self.skip_validation
+            self.monolith_connection_payload["skipValidation"] = self.skip_validation
         if self.skip_permission_tests:
-            self.monolith_connection_payload['skipPermissionTests'] = self.skip_permission_tests
+            self.monolith_connection_payload[
+                "skipPermissionTests"
+            ] = self.skip_permission_tests
 
 
 @dataclass
@@ -93,7 +99,7 @@ class AWSArn:
     resource_type: Optional[str] = field(init=False)
 
     def __post_init__(self):
-        elements = self.id.split(':', 5)
+        elements = self.id.split(":", 5)
         self.arn = elements[0]
         self.partition = elements[1]
         self.service = elements[2]
@@ -102,10 +108,10 @@ class AWSArn:
         self.resource = elements[5]
         self.resource_type = None
 
-        if '/' in self.resource:
-            self.resource_type, self.resource = self.resource.split('/', 1)
-        elif ':' in self.resource:
-            self.resource_type, self.resource = self.resource.split(':', 1)
+        if "/" in self.resource:
+            self.resource_type, self.resource = self.resource.split("/", 1)
+        elif ":" in self.resource:
+            self.resource_type, self.resource = self.resource.split(":", 1)
 
 
 @dataclass
@@ -131,7 +137,7 @@ class ResourceProperties:
     topic_name: Optional[str] = None
 
     def __post_init__(self):
-        self.bucket_arn = f'arn:aws:s3:::{self.bucket_name}'
+        self.bucket_arn = f"arn:aws:s3:::{self.bucket_name}"
 
     def serializable(self):
         serialize_keys = [
@@ -139,13 +145,12 @@ class ResourceProperties:
             "region",
             "account_id",
             "prefix",
-            "suffix" ,
+            "suffix",
             "topic_arn",
             "topic_name",
         ]
-        return {
-            key: getattr(self, key) for key in serialize_keys
-        }
+        return {key: getattr(self, key) for key in serialize_keys}
+
 
 @dataclass
 class EventProperties:
@@ -161,7 +166,9 @@ class EventProperties:
     resource_properties: List[ResourceProperties]
 
     def __post_init__(self):
-        self.event_queue_name = AWSArn(self.event_queue_arn).resource if self.event_queue_arn else None
+        self.event_queue_name = (
+            AWSArn(self.event_queue_arn).resource if self.event_queue_arn else None
+        )
 
     def serializable(self):
         serialize_keys = [
@@ -170,11 +177,11 @@ class EventProperties:
             "collection_region",
             "collection_account_id",
         ]
-        serializable_dict = {
-            key: getattr(self, key) for key in serialize_keys
-        }
+        serializable_dict = {key: getattr(self, key) for key in serialize_keys}
 
-        serializable_dict['resource_properties'] = [resource.serializable() for resource in self.resource_properties]
+        serializable_dict["resource_properties"] = [
+            resource.serializable() for resource in self.resource_properties
+        ]
 
         return serializable_dict
 
