@@ -1,9 +1,11 @@
 CREATE_OR_UPDATE_MONTE_CARLO_CONFIG_TEMPLATE = """
-mutation createOrUpdateMonteCarloConfigTemplate($namespace: String!, $configTemplateJson: String!, $dryRun: Boolean, $resource: String) {
+mutation createOrUpdateMonteCarloConfigTemplate($namespace: String!, $configTemplateJson: String!, 
+    $dryRun: Boolean, $misconfiguredAsWarning: Boolean,  $resource: String) {
   createOrUpdateMonteCarloConfigTemplate(
     configTemplateJson: $configTemplateJson,
     namespace: $namespace,
     dryRun: $dryRun,
+    misconfiguredAsWarning: $misconfiguredAsWarning,
     resource: $resource            
   ) {
     response {
@@ -14,6 +16,7 @@ mutation createOrUpdateMonteCarloConfigTemplate($namespace: String!, $configTemp
       }
       changesApplied
       errorsAsJson
+      warningsAsJson
     }
   }
 }
