@@ -10,7 +10,9 @@ class FunctionComponents:
     exception: Optional[Any] = None
 
 
-def capture_function(function: Callable, params: Optional[Dict] = None) -> FunctionComponents:
+def capture_function(
+    function: Callable, params: Optional[Dict] = None
+) -> FunctionComponents:
     """
     Helper function to capture standard out and any exceptions from a function
     """
